@@ -45,7 +45,7 @@
 
 foreign_t	pl_break(void);
 int		currentBreakLevel(void);
-int		callProlog(Module module, term_t goal, int flags, term_t *ex);
+bool		callProlog(Module module, term_t goal, int flags, term_t *ex);
 int		abortProlog(void);
 bool		prologToplevel(atom_t toplevel);
 int		query_loop(atom_t goal, int loop);
